library("smatr")	
library("RMySQL")
library("MASS")
m <- dbDriver("MySQL")
con <- dbConnect(m, host="xxxxxxx", user= "xxxxxxx", password = "xxxxxxxx", dbname = "scaling")

#number of bins gonna use to slice bone into, calculate mean of each bin, twenty bins=twenty slopes
nBins = 20
bin_size <- 100 / nBins

#as comment enables renaming
mysql_1 <- "SELECT animals.body_mass as mass, avg(slices_w.csa) as csa, avg(slices_w.imax) as imax, avg(slices_w.imin) as imin FROM dimensions, slices_w, animals WHERE animals.order_ = 'Diprotodontia' AND animals.id = slices_w.animal_id AND (100*(slices_w.slice - dimensions.slice_a)/(dimensions.slice_b - dimensions.slice_a)) >= "

mysql_2 <- " AND (100*(slices_w.slice - dimensions.slice_a)/(dimensions.slice_b - dimensions.slice_a)) < "

mysql_3 <- " AND slices_w.bone_code = "

mysql_4 <- " GROUP BY slices_w.animal_id, slices_w.bone_code ORDER BY slices_w.animal_id, slices_w.bone_code"

#list of bones you wanna analyse
bones <- c(2,3,4,5,7,8,10)

#each st is a matrix to store table of results
st1 <- matrix(ncol=8)
st2 <- matrix(ncol=8)
st3 <- matrix(ncol=8)

#for every element in array aka bone in list of bones 
for (bone in bones){
#for all bins ranging from one to number of bins
	for (bin in 1:nBins){
		start <- (bin-1)*bin_size
		end <- start+bin_size
#percent, mean so divide by two
		pc <- end-bin_size/2
		mysqlString <- paste(c(mysql_1, start, mysql_2, end, mysql_3, bone, mysql_4),collapse="")
		bin_data <- dbGetQuery(con, mysqlString)
		
#cis regression, check if variable name has changed, check for feret
#calculate slope, record data
#have to change variable name in mysql_1 if change variable here
		slope_data <- line.cis(log10(bin_data$csa),log10(bin_data$mass))
		row_data <- c(bone, pc, slope_data[2,1], slope_data[2,2], slope_data[2,3], slope_data[1,1], slope_data[1,2], slope_data[1,3])
		st1 <- rbind(st1, row_data)
		rm(row_data)
	
		slope_data <- line.cis(log10(bin_data$imax),log10(bin_data$mass))
		row_data <- c(bone, pc, slope_data[2,1], slope_data[2,2], slope_data[2,3], slope_data[1,1], slope_data[1,2], slope_data[1,3])
		st2 <- rbind(st2, row_data)
		rm(row_data)
	
		slope_data <- line.cis(log10(bin_data$imin),log10(bin_data$mass))
		row_data <- c(bone, pc, slope_data[2,1], slope_data[2,2], slope_data[2,3], slope_data[1,1], slope_data[1,2], slope_data[1,3])
		st3 <- rbind(st3, row_data)
		rm(row_data)
	
	}
}
#name columns interval
# upper/lower confidence limits
colnames(st1) <- c("bone_id", "pc", "slope", "-ci", "+ci", "elevation", "-ciel", "+ciel")
colnames(st2) <- c("bone_id", "pc", "slope", "-ci", "+ci", "elevation", "-ciel", "+ciel")
colnames(st3) <- c("bone_id", "pc", "slope", "-ci", "+ci", "elevation", "-ciel", "+ciel")

#disconnect from database
dbDisconnect(con)

#change location to store results, directory must exist
#take data in st1 matrix into csv file
write.matrix(st1, file = "./Output/mac-csa_mass_bins.csv", sep = ",")
write.matrix(st2, file = "./Output/mac-imax_mass_bins.csv", sep = ",")
write.matrix(st3, file = "./Output/mac-imin_mass_bins.csv", sep = ",")
rm(st1,st2,st3)
