/*
This query generates cross-sectional values normalised by taking the
nth root and dividing by bone length, versus per cent length (pc).
Change the slices_w.bone_code value to the bone of interest.
2 = humerus
3 = radius
4 = ulna
5 = metacarpal
7 = femur
8 = tibia
10 = metatarsal
Results from this query are plotted in Figure 5 of the associated
manuscript
*/
SELECT
 animals.order_ AS 'order',
 concat(animals.genus, ' ', animals.species) AS binomial,
 animals.familiar,
 animals.museum_id,
 dimensions.bone_code,
 (slices_w.slice - dimensions.slice_a)/(dimensions.slice_b - dimensions.slice_a) AS pc,
 sqrt(slices_w.csa)/dimensions.length_ij AS csa_norm,
 pow(slices_w.imax, 1/4)/dimensions.length_ij AS imax_norm,
 pow(slices_w.imin, 1/4)/dimensions.length_ij AS imin_norm
FROM
 slices_w,
 dimensions,
 animals
WHERE
 slices_w.bone_code = 2
 AND slices_w.animal_id = animals.id
 AND dimensions.animal_id = animals.id
 AND slices_w.bone_code = dimensions.bone_code
 AND (slices_w.slice - dimensions.slice_a)/(dimensions.slice_b - dimensions.slice_a) >= 0
 AND (slices_w.slice - dimensions.slice_a)/(dimensions.slice_b - dimensions.slice_a) <= 1
ORDER BY
 order_,
 bone_code,
 binomial,
 museum_id,
 pc
LIMIT
 0, 999999
