library(ape)
library(picante)
library(geiger)
library(phytools)

#phylogeny from Bininda-Emonds et al. 2007
tree<-read.nexus("./Bininda-emonds_2007_mammals.nex")
tree<-tree$mammalST_bestDates

#get only diprotodonts from our data
all.data<-read.csv("./data-table-macropus-giganteus-averaged.csv",row.names=1)
data <- all.data[which(all.data$order=="Diprotodontia"),]
binomials <- make.names(data$binomial,FALSE)
binomials <- gsub('\\.','_',binomials)
dummy.data <- as.matrix(rep(1,length(binomials)))
rownames(dummy.data) <- binomials

missing<-name.check(tree,dummy.data)$tree_not_data
pruned.tree<-drop.tip(tree, missing,root.edge = 1)
pruned.tree<-multi2di(pruned.tree)

png(file = "Diprotodontia-tree.png", width = 600, height = 400)
plot(pruned.tree)
dev.off()

write.tree(pruned.tree, "./Diprotodontia-tree.txt")


