library(data.table)
raw.data<-read.csv("./artioRooDataFromServer.csv")

#reformat
limb.bone.order <- c("humerus","radius","ulna","third metacarpal","femur","tibia","third metatarsal")

reformatted.data <- as.data.frame(matrix(nrow=length(levels(raw.data$museum_id)),ncol=34))
colnames(reformatted.data) <- c("museum","museum_id","order","binomial","familiar","est_body_mass",
                                "length_ij_humerus","csa_humerus","imin_humerus","imax_humerus",   
                                "length_ij_radius","csa_radius","imin_radius","imax_radius",   
                                "length_ij_ulna","csa_ulna","imin_ulna","imax_ulna",
                                "length_ij_third_metacarpal","csa_third_metacarpal","imin_third_metacarpal","imax_third_metacarpal",   
                                "length_ij_femur","csa_femur","imin_femur","imax_femur",   
                                "length_ij_tibia","csa_tibia","imin_tibia","imax_tibia",
                                "length_ij_third_metatarsal","csa_third_metatarsal","imin_third_metatarsal","imax_third_metatarsal")   

#loop over museum ids
counter <- 1
for(current.museum_id in levels(raw.data$museum_id))
{
  current.specimen.data <- raw.data[which(raw.data$museum_id == current.museum_id),]
  current.specimen.identifiers <- current.specimen.data[1,1:6]
  reformatted.current.specimen.data <- as.data.frame(matrix(nrow=1,ncol=34))
  reformatted.current.specimen.data[1:5] <- c(as.character(current.specimen.identifiers[[1]]),as.character(current.specimen.identifiers[[2]]),
                                              as.character(current.specimen.identifiers[[3]]),as.character(current.specimen.identifiers[[4]]),
                                              as.character(current.specimen.identifiers[[5]]))
  reformatted.current.specimen.data[6] <- as.numeric(as.character(current.specimen.data[1,6]))
  
  inner.counter <- 7
  for(current.bone in limb.bone.order)
  {
    data.to.add <- rep(NA_real_,4)
    if(current.bone %in% current.specimen.data$bone_name)
    {
      data.to.add <- current.specimen.data[which(current.specimen.data$bone_name==current.bone),]
      data.to.add <- data.to.add[,8:11]
    }
    data.to.add <- as.numeric(as.character(data.to.add))
    reformatted.current.specimen.data[inner.counter:(inner.counter+3)] <- data.to.add
    inner.counter <- inner.counter+4
  }
  reformatted.data[counter,] <- reformatted.current.specimen.data
  counter <- counter+1
}

#average numerical entries for both Macropus g. specimens
data.to.average <- reformatted.data[which(reformatted.data$binomial=="Macropus giganteus"),]
average <- data.to.average[1,]
average[6:34] <- (average[6:34]+data.to.average[2,6:34])/2.0

#remove Macropus g. lines and add averaged line
reformatted.data <- reformatted.data[-which(reformatted.data$binomial=="Macropus giganteus"),]
reformatted.data <- rbind(reformatted.data, average)


#write output
write.csv(reformatted.data,"./data-table-macropus-giganteus-averaged.csv")
